<?php
namespace MRBS;

/*****************************************************************************\
*                                                                             *
*   File name       session_google.inc                                        *
*                                                                             *
*   Description     Use PHP built-in sessions handling with Google properties *
*                                                                             *
*   Notes           To use this authentication scheme, set in                 *
*                   config.inc.php:                                           *
*                       $auth["session"]  = "google";                         *
*                                                                             *
\*****************************************************************************/

require_once MRBS_ROOT . '/session/functions_session.inc';


function setSessionFromUser ($userDetails)
{
  $_SESSION["UserName"] = $userDetails['name'];
  $_SESSION['userDetails'] = $userDetails;
}


/*
  Display the login form. Used by two routines below.
  Will eventually return to $target_url.
*/
function printLoginForm($target_url)
{
  global $HTTP_REFERER;
  global $returl;
?>
<legend><?php echo get_vocab("please_login") ?></legend>
<div>
  <div class="g-signin2" data-onsuccess="onSignIn"></div>
</div>

<?php
  echo "</div>";  // Close of the contents div
  // Print footer and exit
  print_footer(TRUE);
}

/*
  Target of the form with sets the URL argument "Action=QueryName".
  Will eventually return to URL argument "TargetURL=whatever".
*/
if (isset($action) && ($action == "QueryName"))
{
  print_header(0, 0, 0, 0, "");
  printLoginForm($target_url);
  exit();
}

/* authGet()
 * 
 * Request the user name/password
 * 
 * Returns: Nothing
 */
function authGet()
{
  global $PHP_SELF, $QUERY_STRING;

  print_header(0, 0, 0, 0, "");

  echo "<p>".get_vocab("norights")."</p>\n";

  $target_url = this_page();
  if (isset($QUERY_STRING))
  {
    $target_url = $target_url . "?" . $QUERY_STRING;
  }
  printLoginForm($target_url);

  exit();
}

function getUserName()
{
  if (isset($_SESSION["UserName"]) && ($_SESSION["UserName"] !== ''))
  {
    return $_SESSION["UserName"];
  }

  return NULL;
}

// Print the logon entry on the top banner.
function print_logon_box()
{
  global $PHP_SELF, $QUERY_STRING, $user_list_link, $day, $month, $year;

  $target_url = this_page();
  if (isset($url_base) && ($url_base !== ''))
  {
    $target_url = $url_base . '/' . $target_url;
  }
  if (isset($QUERY_STRING))
  {
    $target_url = $target_url . "?" . $QUERY_STRING;
  }
  $user=getUserName();
  if (isset($user))
  {
    print_report_link($user);
    print_logoff_button($target_url);

    # El script posibilita que nos desautentiquemas también de Google.
?>
<script>
   var form = document.currentScript.previousElementSibling;
   form.onsubmit = function(e) {
      var iframe = document.createElement("iframe");
      iframe.style.display = "none";
      iframe.setAttribute("src", "https://accounts.google.com/logout");
      this.appendChild(iframe);
   }
</script>
<?php
   
    if (isset($user_list_link) && authGetUserLevel($user) >= $page_level[$user_list_link])
    {
      print "<a id=\"user_list_link\" href=\"$user_list_link\">" . get_vocab('user_list') . "</a>\n";
    }
  }
  else
  {
?>
                <div class="g-signin2" data-onsuccess="onSignIn" data-onfailure="onFailure"></div>
<?php
  }
}

global $PHP_SELF, $auth;

// Get non-standard form variables
$action = get_form_var('action', 'string', null, INPUT_POST);
$username = get_form_var('username', 'string', null, INPUT_POST);
$password = get_form_var('password', 'string', null, INPUT_POST);
$target_url = get_form_var('target_url', 'string', null, INPUT_POST);
$returl = get_form_var('returl', 'string', null, INPUT_POST);

if (isset($cookie_path_override))
{
  $cookie_path = $cookie_path_override;
}
else
{
  $cookie_path = $PHP_SELF;
  // Strip off everything after the last '/' in $PHP_SELF
  $cookie_path = preg_replace('/[^\/]*$/', '', $cookie_path);
}

if (!isset($auth["session_php"]["session_expire_time"]))
{
  // Default to the behaviour of previous versions of MRBS, use only
  // session cookies - no persistent cookie.
  $auth["session_php"]["session_expire_time"] = 0;
}

session_name("MRBS_SESSID");  // call before session_set_cookie_params() - see PHP manual
session_set_cookie_params($auth["session_php"]["session_expire_time"],
                          $cookie_path);
                          
// Checking the result of session_start() is not very reliable.   Before PHP 5.3.0
// it always returned TRUE.   Even after 5.3.0 it seems to return TRUE even if the
// session_save_path is not writable.  A warning is generated, but session_start()
// still returns TRUE.
if (FALSE === session_start())
{
  trigger_error("MRBS: could not start session", E_USER_WARNING);
  fatal_error("MRBS: server configuration error.");
}

// Check to see if we've been inactive for longer than allowed and if so logout
// the user
if (!empty($auth["session_php"]["inactivity_expire_time"]))
{
  if (isset($_SESSION['LastActivity']) &&
      ((time() - $_SESSION['LastActivity']) > $auth["session_php"]["inactivity_expire_time"]))
  {
    unset($_SESSION["UserName"]);
  }
  // Ajax requests don't count as activity, unless it's the special Ajax request used
  // to record client side activity
  $ajax = get_form_var('ajax', 'int');
  $activity = get_form_var('activity', 'int');
  if ($activity || !$ajax || !isset($_SESSION['LastActivity']))
  {
    $_SESSION['LastActivity'] = time();
  }
}

/*
  Target of the form with sets the URL argument "Action=SetName".
  Will eventually return to URL argument "TargetURL=whatever".
*/

if (isset($action) && ($action == "SetName"))
{

  /* First make sure the password is valid */
  if ($username == "")
  {

    // Unset the session variables
    session_unset();
    session_destroy();
  }
  else
  {
    if (!authValidateUser($username, $password))
    {
      print_header(0, 0, 0, 0, "");
      echo "<p>".get_vocab('unknown_user')."</p>\n";
      printLoginForm($target_url);
      exit();
    }

    //$_SESSION["UserName"] = $username;
  }
  // preserve the original $HTTP_REFERER by sending it as a GET parameter
  if (!empty($returl))
  {
    // check to see whether there's a query string already
    if (strpos($target_url, '?') === false)
    {
      $target_url .= "?returl=" . urlencode($returl);
    }
    else
    {
      $target_url .= "&returl=" . urlencode($returl);
    }
  }
  // Problems have been reported on Windows IIS with session data not being
  // written out without a call to session_write_close()
  session_write_close();
  header ("Location: $target_url"); /* Redirect browser to initial page */
  /* Note HTTP 1.1 mandates an absolute URL. Most modern browsers support relative URLs,
    which allows to work around problems with DNS inconsistencies in the server name.
    Anyway, if the browser cannot redirect automatically, the manual link below will work. */
  print_header(0, 0, 0, 0, "");
  echo "<br>\n";
  echo "<p>Please click <a href=\"".htmlspecialchars($target_url)."\">here</a> if you're not redirected automatically to the page you requested.</p>\n";

  // Print footer and exit
  print_footer(TRUE);
}

